@@ -53,7 +53,7 @@ def test_docker_env_file(appcenter, app_name):
         app.add_to_local_appcenter()
         appcenter.update()
         app.install()
-        app.verify(joined=False)
+        app.verify()
         env_file = f'/var/lib/univention-appcenter/apps/{app_name}/compose/{app_name}.env'
         subprocess.call(['ls', '-la', env_file])
         env_content = open(env_file).read()
